isSealedTopNode property
bool
get
isSealedTopNode
Returns true if this class is the top node of a sealed hierarchy.
Implementation
bool get isSealedTopNode => identical(sealedTopNode, this);
Returns true if this class is the top node of a sealed hierarchy.
bool get isSealedTopNode => identical(sealedTopNode, this);