containsTableNamed method
Returns true if the database contains a table with the given tableName.
Implementation
bool containsTableNamed(String tableName, {String? schema}) {
return (findTableNamed(tableName, schema: schema) != null);
}
Returns true if the database contains a table with the given tableName.
bool containsTableNamed(String tableName, {String? schema}) {
return (findTableNamed(tableName, schema: schema) != null);
}