ExceptionClassDefinition class final

A ClassDefinition specialization that represents an exception.

Inheritance

Constructors

ExceptionClassDefinition({required String className, required List<SerializableModelFieldDefinition> fields, required String fileName, required bool serverOnly, required String sourceFileName, required TypeDefinition type, required bool isSealed, List<InheritanceDefinition>? childClasses, InheritanceDefinition? extendsClass, List<String>? documentation, List<String> subDirParts = const [], String? sharedPackageName})
Create a new ExceptionClassDefinition.

Properties

childClasses List<InheritanceDefinition>
If set to a List of InheritanceDefinition the class is a parent class that stores the child classes.
getter/setter pairinherited
className String
finalinherited
descendantClasses List<ExceptionClassDefinition>
Returns a list of all descendant classes. This includes all child classes and their descendants. If the class has no child classes, an empty list is returned.
no setteroverride
documentation List<String>?
The documentation of this class, line by line.
finalinherited
everyParentIsSealed bool
Returns true if all parent classes are sealed. Returns true if the class does not have a parent class.
no setterinherited
extendsClass ↔ InheritanceDefinition?
If set to InheritanceDefinition the class extends another class and stores the ClassDefinition of its parent.
getter/setter pairinherited
fields List<SerializableModelFieldDefinition>
The fields of this class / exception.
getter/setter pairinherited
fieldsIncludingInherited List<SerializableModelFieldDefinition>
Returns a list of all fields in this class, including inherited fields. Non-tail fields are ordered top-down through the inheritance chain. Tail fields are ordered bottom-up so that root parent tail fields appear last.
no setterinherited
fileName String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inheritedFields List<SerializableModelFieldDefinition>
Returns a list of all fields in the parent class. If there is no parent class, an empty list is returned.
no setterinherited
isParentClass bool
Returns true if this class is a parent class or sealed.
no setterinherited
isSealed bool
If set to true the class is sealed.
finalinherited
isSealedTopNode bool
Returns true if this class is the top node of a sealed hierarchy.
no setterinherited
isSharedModel bool
Whether this model is declared in a shared package. Such models are not generated on the server or client side, but on its own shared package.
no setterinherited
parentClass ExceptionClassDefinition?
Returns the ClassDefinition of the parent class. If there is no parent class, null is returned.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sealedTopNode ExceptionClassDefinition?
Returns the top node of the sealed hierarchy. If the class is the top node it returns itself. If the class is not part of a sealed hierarchy, null is returned.
no setteroverride
serverOnly bool
finalinherited
sharedPackageName String?
finalinherited
sourceFileName String
finalinherited
subDirParts List<String>
finalinherited
type TypeDefinition
finalinherited
typeName String
Returns the type name used in validation messages.
no setterinherited

Methods

fileRef() String
Generate the file reference String to this file.
inherited
findField(String name) SerializableModelFieldDefinition?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited