parentClass property
Returns the ClassDefinition of the parent class.
If there is no parent class, null is returned.
Implementation
@override
ExceptionClassDefinition? get parentClass =>
super.parentClass as ExceptionClassDefinition?;
Returns the ClassDefinition of the parent class.
If there is no parent class, null is returned.
@override
ExceptionClassDefinition? get parentClass =>
super.parentClass as ExceptionClassDefinition?;