sealedTopNode property

  1. @override
ExceptionClassDefinition? get sealedTopNode
override

Returns the top node of the sealed hierarchy. If the class is the top node it returns itself. If the class is not part of a sealed hierarchy, null is returned.

Implementation

@override
ExceptionClassDefinition? get sealedTopNode =>
    super.sealedTopNode as ExceptionClassDefinition?;