serializeAsJsonbByDefault property
Whether serializable fields default to jsonb instead of json when
stored in the database.
Implementation
final bool serializeAsJsonbByDefault;
Whether serializable fields default to jsonb instead of json when
stored in the database.
final bool serializeAsJsonbByDefault;