serverPackageDirectoryPathParts property
The parts of the absolute, normalized path where the server package is located. Anchored at GeneratorConfig.load time.
Implementation
final List<String> serverPackageDirectoryPathParts;
The parts of the absolute, normalized path where the server package is located. Anchored at GeneratorConfig.load time.
final List<String> serverPackageDirectoryPathParts;