LastOrNullOnListString extension

Returns the last element of the list, or null if the list is empty.

Used to get the latest migration version from the list of migration versions.

on

Properties

lastOrNull String?

Available on List<String>, provided by the LastOrNullOnListString extension

no setter