PostgresColumnMigrationPgSqlGenerator extension

on
  • ColumnMigration

Properties

physicalName String

Available on ColumnMigration, provided by the PostgresColumnMigrationPgSqlGenerator extension

The physical name of the column to be used in the SQL statements, taking renames into consideration. Ensure that any using statement happen after the rename statements.
no setter

Methods

toPgSql({required String tableName, required ColumnDefinition columnDefinition}) String

Available on ColumnMigration, provided by the PostgresColumnMigrationPgSqlGenerator extension