physicalName property

String get physicalName

The physical name of the column to be used in the SQL statements, taking renames into consideration. Ensure that any using statement happen after the rename statements.

Implementation

String get physicalName => newColumnName ?? columnName;