PostgresSqlGenerator class

Constructors

PostgresSqlGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateDatabaseDefinitionSql(DatabaseDefinition databaseDefinition, {required List<DatabaseMigrationVersion> installedModules}) String
generateDatabaseMigrationSql(DatabaseMigration databaseMigration, {required List<DatabaseMigrationVersion> installedModules, required List<DatabaseMigrationVersion> removedModules}) String
getColumnDefault(TypeDefinition columnType, dynamic defaultValue, String tableName) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited