SerializableModelDefinition class sealed

An abstract representation of a yaml file in the protocol directory.

Implementers

Properties

className String
final
fileName String
final
hashCode int
The hash code for this object.
no setterinherited
isSharedModel bool
Whether this model is declared in a shared package. Such models are not generated on the server or client side, but on its own shared package.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverOnly bool
final
sharedPackageName String?
final
sourceFileName String
final
subDirParts List<String>
final
type TypeDefinition
final

Methods

fileRef() String
Generate the file reference String to this file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited