shouldCreateUniqueIndex property
Whether this field should have a unique index auto-generated for it.
Implementation
final bool shouldCreateUniqueIndex;
Whether this field should have a unique index auto-generated for it.
final bool shouldCreateUniqueIndex;