nullsDistinct property
Whether null values should be considered distinct in this unique index.
A null value uses the database default behavior.
Implementation
final bool? nullsDistinct;
Whether null values should be considered distinct in this unique index.
A null value uses the database default behavior.
final bool? nullsDistinct;