ClassDefinition class sealed
A representation of a yaml file in the protocol directory defining a class or exception.
See also:
- Inheritance
-
- Object
- SerializableModelDefinition
- ClassDefinition
- Implementers
Properties
-
childClasses
↔ List<
InheritanceDefinition> -
If set to a List of
InheritanceDefinitionthe class is a parent class that stores the child classes.getter/setter pair - className → String
-
finalinherited
-
descendantClasses
→ List<
ClassDefinition> -
Returns a list of all descendant classes.
This includes all child classes and their descendants.
If the class has no child classes, an empty list is returned.
no setter
-
documentation
→ List<
String> ? -
The documentation of this class, line by line.
final
- everyParentIsSealed → bool
-
Returns
trueif all parent classes are sealed. Returnstrueif the class does not have a parent class.no setter - extendsClass ↔ InheritanceDefinition?
-
If set to
InheritanceDefinitionthe class extends another class and stores the ClassDefinition of its parent.getter/setter pair -
fields
↔ List<
SerializableModelFieldDefinition> -
The fields of this class / exception.
getter/setter pair
-
fieldsIncludingInherited
→ List<
SerializableModelFieldDefinition> -
Returns a list of all fields in this class, including inherited fields.
Non-tail fields are ordered top-down through the inheritance chain. Tail
fields are ordered bottom-up so that root parent tail fields appear last.
no setter
- fileName → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inheritedFields
→ List<
SerializableModelFieldDefinition> -
Returns a list of all fields in the parent class.
If there is no parent class, an empty list is returned.
no setter
- isParentClass → bool
-
Returns
trueif this class is a parent class or sealed.no setter - isSealed → bool
-
If set to true the class is sealed.
final
- isSealedTopNode → bool
-
Returns
trueif this class is the top node of a sealed hierarchy.no setter -
Whether this model is declared in a shared package. Such models are not
generated on the server or client side, but on its own shared package.
no setterinherited
- parentClass → ClassDefinition?
-
Returns the
ClassDefinitionof the parent class. If there is no parent class,nullis returned.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sealedTopNode → ClassDefinition?
-
Returns the top node of the sealed hierarchy. If the class is the top node
it returns itself. If the class is not part of a sealed hierarchy,
nullis returned.no setter - serverOnly → bool
-
finalinherited
-
finalinherited
- sourceFileName → String
-
finalinherited
-
subDirParts
→ List<
String> -
finalinherited
- type → TypeDefinition
-
finalinherited
- typeName → String
-
Returns the type name used in validation messages.
no setter
Methods
-
fileRef(
) → String -
Generate the file reference String to this file.
inherited
-
findField(
String name) → SerializableModelFieldDefinition? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited