DatabaseDefinitionUtils extension
Utility methods for DatabaseDefinition.
- on
-
- DatabaseDefinition
Methods
-
containsTableNamed(
String tableName) → bool -
Available on DatabaseDefinition, provided by the DatabaseDefinitionUtils extension
Returns true if the database contains a table with the giventableName. -
findTableNamed(
String tableName) → TableDefinition? -
Available on DatabaseDefinition, provided by the DatabaseDefinitionUtils extension
Finds a table by its name, or returns null if no table with the given name.