findTableNamed method
Finds a table by its name, or returns null if no table with the given name.
Implementation
TableDefinition? findTableNamed(String tableName) {
return tables.firstWhereOrNull((table) => table.name == tableName);
}
Finds a table by its name, or returns null if no table with the given name.
TableDefinition? findTableNamed(String tableName) {
return tables.firstWhereOrNull((table) => table.name == tableName);
}