sharedModelsSourcePathsParts property
The path parts to packages of shared models. The key is the package name, the value is the path parts to the package relative to the server package.
Implementation
final Map<String, List<String>> sharedModelsSourcePathsParts;