LastOrNullOnListString extension
Returns the last element of the list, or null if the list is empty.
Used to get the latest migration version from the list of migration versions.
Properties
- lastOrNull → String?
-
Available on List<
String> , provided by the LastOrNullOnListString extensionno setter