MigrationGenerator class
Constructors
- MigrationGenerator({required Directory directory, required String projectName})
Properties
- directory → Directory
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createMigration(
{String? tag, required bool force, required GeneratorConfig config, bool write = true}) → Future< MigrationVersionArtifacts?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
repairMigration(
{String? tag, required bool force, required String runMode, required DatabaseDialect dialect, String? targetMigrationVersion}) → Future< File?> - Creates a repair migration that will bring the database up to date with the targeted migration version.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createVersionName(
String? tag) → String