TableDefinitionUtils extension
Utility methods for TableDefinition.
- on
-
- TableDefinition
Methods
-
containsColumnNamed(
String columnName) → bool -
Available on TableDefinition, provided by the TableDefinitionUtils extension
Returns true if the table contains a column with the givencolumnName. -
containsForeignKeyNamed(
String keyName) → bool -
Available on TableDefinition, provided by the TableDefinitionUtils extension
Returns true if the table contains a foreign key with the givenkeyName. -
containsIndexNamed(
String indexName) → bool -
Available on TableDefinition, provided by the TableDefinitionUtils extension
Returns true if the table contains an index with the givenindexName. -
findColumnNamed(
String columnName) → ColumnDefinition? -
Available on TableDefinition, provided by the TableDefinitionUtils extension
Finds a column by its name, or returns null if no column with the given name is found. -
findForeignKeyDefinitionNamed(
String keyName, {bool ignoreCase = false}) → ForeignKeyDefinition? -
Available on TableDefinition, provided by the TableDefinitionUtils extension
Finds a foreign key by its name, or returns null if no key with the given name is found. -
findIndexNamed(
String indexName, {bool ignoreCase = false}) → IndexDefinition? -
Available on TableDefinition, provided by the TableDefinitionUtils extension
Finds an index by its name, or returns null if no index with the given name is found.